python-hyperscan
================

.. image:: https://img.shields.io/pypi/v/hyperscan.svg
   :target: https://pypi.python.org/pypi/hyperscan

.. image:: https://img.shields.io/pypi/pyversions/hyperscan.svg
   :target: https://pypi.python.org/pypi/hyperscan

A CPython extension for `Hyperscan <https://01.org/hyperscan>`_.
